@@ -1,23 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1b3-pre"
-#define PACKAGE_STRING "am-utils 6.1b3-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_STRING "am-utils 6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd5.1"
+#define HOST_OS "freebsd5.3"
 #define HOST_OS_NAME "freebsd5"
-#define HOST_OS_VERSION "5.1"
+#define HOST_OS_VERSION "5.3"
 #define HOST_ARCH "i386"
-#define HOST_NAME "a-freebsd51.fsl.cs.sunysb.edu"
+#define DISTRO_NAME "none"
+#define HOST_NAME "a-freebsd53.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Aug  2 13:35:19 EDT 2003"
+#define CONFIG_DATE "Thu May 11 11:27:43 EDT 2006"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1b3-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1b3-pre"
+#define VERSION "6.2a2"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -30,10 +31,12 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "5.1"
+#ifdef __cplusplus
+#include <stdlib.h>
+#endif
+#define HOST_HEADER_VERSION "5.3"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -41,6 +44,7 @@
 #define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
 #define GETPGRP_VOID 1
+#define HAVE___RPC_GET_LOCAL_UID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
@@ -60,15 +64,15 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
-#define HAVE_HES_INIT 1
-#define HAVE_HESIOD_INIT 1
-#define HAVE_HESIOD_TO_BIND 1
+#define HAVE_HSTRERROR 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MEMSET 1
 #define HAVE_MKDIR 1
 #define HAVE_MKSTEMP 1
+#define HAVE_MLOCKALL 1
 #define HAVE_MOUNT 1
 #define HAVE_REGCOMP 1
 #define HAVE_REGEXEC 1
@@ -80,12 +84,17 @@
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STATVFS 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
 #define HAVE_SVC_GETREQ 1
@@ -97,10 +106,15 @@
 #define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
+#define HAVE_HES_INIT 1
+#define HAVE_HESIOD_INIT 1
+#define HAVE_HESIOD_TO_BIND 1
 #define HAVE_CLNT_SPERRNO 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
@@ -148,6 +162,7 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_FS_MSDOSFS_MSDOSFSMOUNT_H 1
 #define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
 #define HAVE_NET_IF_H 1
@@ -185,6 +200,7 @@
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_SOCKIO_H 1
 #define HAVE_SYS_STAT_H 1
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLIMITS_H 1
 #define HAVE_SYS_SYSLOG_H 1
@@ -202,8 +218,8 @@
 #define HAVE_FCNTL_H 1
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
-#define HAVE_HESIOD_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
 #define HAVE_NETCONFIG_H 1
@@ -222,15 +238,16 @@
 #define HAVE_SYSLOG_H 1
 #define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
-#define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_HESIOD_H 1
+#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
-#define am_nfs_fh3 nfs_fh3_freebsd3
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
@@ -241,9 +258,11 @@
 #define AUTH_CREATE_GIDLIST_TYPE gid_t
 #define SVC_IN_ARG_TYPE caddr_t
 #define cdfs_args_t struct iso_args
+#define pcfs_args_t struct msdosfs_args
 #define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -261,8 +280,11 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCAT 1
+#define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
@@ -273,13 +295,22 @@
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
+#define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_CDFS_ARGS_T_FLAGS 1
 #define HAVE_CDFS_ARGS_T_FSPEC 1
 #define HAVE_CDFS_ARGS_T_SSECTOR 1
+#define HAVE_PCFS_ARGS_T_DIRMASK 1
+#define HAVE_PCFS_ARGS_T_FSPEC 1
+#define HAVE_PCFS_ARGS_T_GID 1
+#define HAVE_PCFS_ARGS_T_MASK 1
+#define HAVE_PCFS_ARGS_T_UID 1
 #define HAVE_UFS_ARGS_T_FSPEC 1
 #define HAVE_STRUCT_STATFS_F_FSTYPENAME 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
+#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
+#define HAVE_NFS_ARGS_T_ACREGMAX 1
+#define HAVE_NFS_ARGS_T_ADDRLEN 1
 #define HAVE_NFS_ARGS_T_FHSIZE 1
 #define HAVE_NFS_ARGS_T_PROTO 1
 #define HAVE_NFS_ARGS_T_SOTYPE 1
@@ -288,13 +319,16 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_HESIOD 1
+#define HAVE_DBM_OPEN 1
+#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_UNIONFS 1
@@ -302,7 +336,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -324,6 +357,7 @@
 #define MNTTAB_TYPE_PCFS "msdosfs"
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_IGNORE 0x800000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
@@ -353,6 +387,9 @@
 #define MNT2_CDFS_OPT_EXTATT 0x4
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
+#define MNT2_PCFS_OPT_LONGNAME 0x2
+#define MNT2_PCFS_OPT_NOWIN95 0x4
+#define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
 #define HAVE_LIBWRAP 1
